@@ -280,7 +280,7 @@ download_file <- function(input,
                     show_rownames <- attr(data, "show_rownames")
                     openxlsx::write.xlsx(data, file, 
                                          asTable   = TRUE, 
-                                         row.names = !is.null(show_rownames) && show_rownames)
+                                         rowNames = !is.null(show_rownames) && show_rownames)
                 }
             } else {
                 writexl::write_xlsx(data, file)
